aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/google/protobuf/util/json_util.h
diff options
context:
space:
mode:
authorGravatar Brendan McCarthy <brendan@oddsoftware.net>2017-03-17 22:47:38 +1000
committerGravatar Brendan McCarthy <brendan@oddsoftware.net>2017-03-17 22:47:38 +1000
commit89eb4e51b24f7417224b47faf32503d11b6b1bc0 (patch)
tree1421c70b8eac263f872de8b37f036c3c60108541 /src/google/protobuf/util/json_util.h
parent1eee3202fce4953a9c0c3adbf357ed10bd71e01e (diff)
Add option to preserve original proto field names
Diffstat (limited to 'src/google/protobuf/util/json_util.h')
-rw-r--r--src/google/protobuf/util/json_util.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/google/protobuf/util/json_util.h b/src/google/protobuf/util/json_util.h
index 439d137f..dd9a736f 100644
--- a/src/google/protobuf/util/json_util.h
+++ b/src/google/protobuf/util/json_util.h
@@ -64,13 +64,13 @@ struct JsonPrintOptions {
// Whether to always print enums as ints. By default they are rendered as
// strings.
bool always_print_enums_as_ints;
- // Whether to convert field names to snake case
- bool use_snake_case_for_field_names;
+ // Whether to preserve proto field names
+ bool preserve_proto_field_names;
JsonPrintOptions() : add_whitespace(false),
always_print_primitive_fields(false),
always_print_enums_as_ints(false),
- use_snake_case_for_field_names(false) {
+ preserve_proto_field_names(false) {
}
};